==> openejb-jee-3.1.4-sources.jar: org/apache/openejb/jee/oejb2/AuthMethodType.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.openejb.jee.oejb2;

import javax.xml.bind.annotation.XmlEnum;
import javax.xml.bind.annotation.XmlEnumValue;


/**
 * <p>Java class for auth-methodType.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * <p>
 * <pre>
 * &lt;simpleType name="auth-methodType">
 *   &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string">
 *     &lt;enumeration value="BASIC"/>
 *     &lt;enumeration value="DIGEST"/>
 *     &lt;enumeration value="CLIENT-CERT"/>
 *     &lt;enumeration value="NONE"/>
 *   &lt;/restriction>
 * &lt;/simpleType>
 * </pre>
 * 
 */
@XmlEnum
public enum AuthMethodType {

    BASIC("BASIC"),
    DIGEST("DIGEST"),
    @XmlEnumValue("CLIENT-CERT")
    CLIENT_CERT("CLIENT-CERT"),
    @XmlEnumValue("WS-SECURITY")
    WS_SECURITY("WS-SECURITY"),
    NONE("NONE");
    private final String value;

    AuthMethodType(String v) {
        value = v;
    }

    public String value() {
        return value;
    }

    public static AuthMethodType fromValue(String v) {
        for (AuthMethodType c: AuthMethodType.values()) {
            if (c.value.equals(v)) {
                return c;
            }
        }
        throw new IllegalArgumentException(v.toString());
    }

}

==> openejb-jee-4.7.2-sources.jar: org/apache/openejb/jee/oejb2/AuthMethodType.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.openejb.jee.oejb2;

import javax.xml.bind.annotation.XmlEnum;
import javax.xml.bind.annotation.XmlEnumValue;


/**
 * <p>Java class for auth-methodType.
 * <p/>
 * <p>The following schema fragment specifies the expected content contained within this class.
 * <p/>
 * <pre>
 * &lt;simpleType name="auth-methodType">
 *   &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string">
 *     &lt;enumeration value="BASIC"/>
 *     &lt;enumeration value="DIGEST"/>
 *     &lt;enumeration value="CLIENT-CERT"/>
 *     &lt;enumeration value="NONE"/>
 *   &lt;/restriction>
 * &lt;/simpleType>
 * </pre>
 */
@XmlEnum
public enum AuthMethodType {

    BASIC("BASIC"),
    DIGEST("DIGEST"),
    @XmlEnumValue("CLIENT-CERT")
    CLIENT_CERT("CLIENT-CERT"),
    @XmlEnumValue("WS-SECURITY")
    WS_SECURITY("WS-SECURITY"),
    NONE("NONE");
    private final String value;

    AuthMethodType(final String v) {
        value = v;
    }

    public String value() {
        return value;
    }

    public static AuthMethodType fromValue(final String v) {
        for (final AuthMethodType c : AuthMethodType.values()) {
            if (c.value.equals(v)) {
                return c;
            }
        }
        throw new IllegalArgumentException(v.toString());
    }

}
